@@ -1,21 +1,8 @@
 # Copyright 2017 Palantir Technologies, Inc.
 import sys
-import pytest
-from pyls import uris
+from test.fixtures import DOC_URI, DOC
 from pyls.workspace import Document
 
-DOC_URI = uris.from_fs_path(__file__)
-DOC = """import sys
-
-def main():
-    print sys.stdin.read()
-"""
-
-
-@pytest.fixture
-def doc():
-    return Document(DOC_URI, DOC)
-
 
 def test_document_props(doc):
     assert doc.uri == DOC_URI
@@ -27,6 +14,12 @@ def test_document_lines(doc):
     assert doc.lines[0] == 'import sys\n'
 
 
+def test_document_source_unicode():
+    document_mem = Document(DOC_URI, u'my source')
+    document_disk = Document(DOC_URI)
+    assert isinstance(document_mem.source, type(document_disk.source))
+
+
 def test_offset_at_position(doc):
     assert doc.offset_at_position({'line': 0, 'character': 8}) == 8
     assert doc.offset_at_position({'line': 1, 'character': 5}) == 16
